--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET client_encoding = 'SQL_ASCII';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

--
-- Name: plpgsql; Type: PROCEDURAL LANGUAGE; Schema: -; Owner: postgres
--

CREATE PROCEDURAL LANGUAGE plpgsql;


ALTER PROCEDURAL LANGUAGE plpgsql OWNER TO postgres;

SET search_path = public, pg_catalog;

--
-- Name: compress_tables(); Type: FUNCTION; Schema: public; Owner: ulog2
--

CREATE FUNCTION compress_tables() RETURNS void
    LANGUAGE sql
    AS $$

  -- look for packets in table _tcp and not in table ulog2

  DELETE FROM tcp WHERE _tcp_id NOT IN (SELECT _id FROM ulog2);

  -- XXX note: could be rewritten (need to see what is more efficient) as:

  -- DELETE FROM tcp WHERE _tcp_id IN (SELECT tcp._tcp_id FROM tcp LEFT OUTER JOIN ulog2  ON (tcp._tcp_id = ulog2._id) WHERE ulog2._id IS NULL);

  DELETE FROM mac WHERE _mac_id NOT IN (SELECT _id FROM ulog2);

  DELETE FROM udp WHERE _udp_id NOT IN (SELECT _id FROM ulog2);

  DELETE FROM sctp WHERE _sctp_id NOT IN (SELECT _id FROM ulog2);

  DELETE FROM icmp WHERE _icmp_id NOT IN (SELECT _id FROM ulog2);

  -- look for packets in table ulog2 with proto tcp (or ipv6 ?) and not in table tcp

  DELETE FROM ulog2 WHERE ulog2.ip_protocol = '6' AND _id NOT IN (SELECT _tcp_id FROM tcp);

  DELETE FROM ulog2 WHERE ulog2.ip_protocol = '17' AND _id NOT IN (SELECT _udp_id FROM udp);

  DELETE FROM ulog2 WHERE ulog2.ip_protocol = '132' AND _id NOT IN (SELECT _sctp_id FROM sctp);

  DELETE FROM ulog2 WHERE ulog2.ip_protocol = '2' AND _id NOT IN (SELECT _icmp_id FROM icmp);

$$;


ALTER FUNCTION public.compress_tables() OWNER TO ulog2;

--
-- Name: delete_ct_flow(bigint); Type: FUNCTION; Schema: public; Owner: ulog2
--

CREATE FUNCTION delete_ct_flow(_ct_packet_id bigint) RETURNS void
    LANGUAGE sql
    AS $_$

  -- remember : table with most constraints first

  DELETE FROM ulog2_ct WHERE ulog2_ct._ct_id = $1;

$_$;


ALTER FUNCTION public.delete_ct_flow(_ct_packet_id bigint) OWNER TO ulog2;

--
-- Name: delete_packet(bigint); Type: FUNCTION; Schema: public; Owner: ulog2
--

CREATE FUNCTION delete_packet(_packet_id bigint) RETURNS void
    LANGUAGE sql
    AS $_$

  -- remember : table with most constraints first

  DELETE FROM icmp  WHERE icmp._icmp_id = $1;

  DELETE FROM tcp   WHERE tcp._tcp_id   = $1;

  DELETE FROM udp   WHERE udp._udp_id   = $1;

  DELETE FROM sctp   WHERE sctp._sctp_id   = $1;

  DELETE FROM ulog2 WHERE ulog2._id     = $1;

$_$;


ALTER FUNCTION public.delete_packet(_packet_id bigint) OWNER TO ulog2;

--
-- Name: insert_ct(integer, inet, inet, integer, integer, integer, bigint, bigint, inet, inet, integer, integer, integer, bigint, bigint, integer, integer, bigint, bigint, bigint, bigint, bigint, integer); Type: FUNCTION; Schema: public; Owner: ulog2
--

CREATE FUNCTION insert_ct(_oob_family integer, _orig_ip_saddr inet, _orig_ip_daddr inet, _orig_ip_protocol integer, _orig_l4_sport integer, _orig_l4_dport integer, _orig_raw_pktlen bigint, _orig_raw_pktcount bigint, _reply_ip_saddr inet, _reply_ip_daddr inet, _reply_ip_protocol integer, _reply_l4_sport integer, _reply_l4_dport integer, _reply_raw_pktlen bigint, _reply_raw_pktcount bigint, _icmp_code integer, _icmp_type integer, _ct_mark bigint, _flow_start_sec bigint, _flow_start_usec bigint, _flow_end_sec bigint, _flow_end_usec bigint, _ct_event integer) RETURNS bigint
    LANGUAGE sql
    AS $_$

        INSERT INTO ulog2_ct (oob_family, orig_ip_saddr_str, orig_ip_daddr_str, orig_ip_protocol,

                        orig_l4_sport, orig_l4_dport, orig_raw_pktlen, orig_raw_pktcount,

                        reply_ip_saddr_str, reply_ip_daddr_str, reply_ip_protocol,

                        reply_l4_sport, reply_l4_dport, reply_raw_pktlen, reply_raw_pktcount,

                        icmp_code, icmp_type, ct_mark, 

                        flow_start_sec, flow_start_usec,

                        flow_end_sec, flow_end_usec, ct_event)

                VALUES ($1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14,$15,$16,$17,$18,$19,$20,$21,$22,$23);

        SELECT currval('ulog2_ct__ct_id_seq');

$_$;


ALTER FUNCTION public.insert_ct(_oob_family integer, _orig_ip_saddr inet, _orig_ip_daddr inet, _orig_ip_protocol integer, _orig_l4_sport integer, _orig_l4_dport integer, _orig_raw_pktlen bigint, _orig_raw_pktcount bigint, _reply_ip_saddr inet, _reply_ip_daddr inet, _reply_ip_protocol integer, _reply_l4_sport integer, _reply_l4_dport integer, _reply_raw_pktlen bigint, _reply_raw_pktcount bigint, _icmp_code integer, _icmp_type integer, _ct_mark bigint, _flow_start_sec bigint, _flow_start_usec bigint, _flow_end_sec bigint, _flow_end_usec bigint, _ct_event integer) OWNER TO ulog2;

--
-- Name: insert_hardware_header(bigint, integer, character varying); Type: FUNCTION; Schema: public; Owner: ulog2
--

CREATE FUNCTION insert_hardware_header(hw_id bigint, hw_type integer, hw_addr character varying) RETURNS bigint
    LANGUAGE sql
    AS $_$

        INSERT INTO hwhdr (_hw_id,raw_type,raw_header)

                VALUES ($1,$2,$3);

        SELECT currval('ulog2__id_seq');

$_$;


ALTER FUNCTION public.insert_hardware_header(hw_id bigint, hw_type integer, hw_addr character varying) OWNER TO ulog2;

--
-- Name: insert_icmp(bigint, integer, integer, integer, integer, integer, integer); Type: FUNCTION; Schema: public; Owner: ulog2
--

CREATE FUNCTION insert_icmp(icmp_id bigint, icmp_type integer, icmp_code integer, icmp_echoid integer, icmp_echoseq integer, icmp_gateway integer, icmp_fragmtu integer) RETURNS bigint
    LANGUAGE sql
    AS $_$

        INSERT INTO icmp (_icmp_id,icmp_type,icmp_code,icmp_echoid,icmp_echoseq,icmp_gateway,icmp_fragmtu)

                VALUES ($1,$2,$3,$4,$5,$6,$7);

        SELECT currval('ulog2__id_seq');

$_$;


ALTER FUNCTION public.insert_icmp(icmp_id bigint, icmp_type integer, icmp_code integer, icmp_echoid integer, icmp_echoseq integer, icmp_gateway integer, icmp_fragmtu integer) OWNER TO ulog2;

--
-- Name: insert_icmpv6(bigint, integer, integer, integer, integer, integer); Type: FUNCTION; Schema: public; Owner: ulog2
--

CREATE FUNCTION insert_icmpv6(icmpv6_id bigint, icmpv6_type integer, icmpv6_code integer, icmpv6_echoid integer, icmpv6_echoseq integer, icmpv6_csum integer) RETURNS bigint
    LANGUAGE sql
    AS $_$

        INSERT INTO icmpv6 (_icmpv6_id,icmpv6_type,icmpv6_code,icmpv6_echoid,icmpv6_echoseq,icmpv6_csum)

                VALUES ($1,$2,$3,$4,$5,$6);

        SELECT currval('ulog2__id_seq');

$_$;


ALTER FUNCTION public.insert_icmpv6(icmpv6_id bigint, icmpv6_type integer, icmpv6_code integer, icmpv6_echoid integer, icmpv6_echoseq integer, icmpv6_csum integer) OWNER TO ulog2;

--
-- Name: insert_ip_packet(integer, integer, character varying, integer, character varying, character varying, integer, inet, inet, integer); Type: FUNCTION; Schema: public; Owner: ulog2
--

CREATE FUNCTION insert_ip_packet(oob_time_sec integer, oob_time_usec integer, oob_prefix character varying, oob_mark integer, oob_in character varying, oob_out character varying, oob_family integer, ip_saddr_str inet, ip_daddr_str inet, ip_protocol integer) RETURNS bigint
    LANGUAGE sql
    AS $_$

        INSERT INTO ulog2 (oob_time_sec,oob_time_usec,oob_prefix,oob_mark,

                        oob_in,oob_out,oob_family,ip_saddr_str,ip_daddr_str,ip_protocol)

                VALUES ($1,$2,$3,$4,$5,$6,$7,$8,$9,10);

        SELECT currval('ulog2__id_seq');

$_$;


ALTER FUNCTION public.insert_ip_packet(oob_time_sec integer, oob_time_usec integer, oob_prefix character varying, oob_mark integer, oob_in character varying, oob_out character varying, oob_family integer, ip_saddr_str inet, ip_daddr_str inet, ip_protocol integer) OWNER TO ulog2;

--
-- Name: insert_ip_packet_full(integer, integer, integer, character varying, integer, character varying, character varying, integer, inet, inet, integer, integer, integer, integer, integer, integer, integer, integer, integer); Type: FUNCTION; Schema: public; Owner: ulog2
--

CREATE FUNCTION insert_ip_packet_full(oob_time_sec integer, oob_time_usec integer, oob_hook integer, oob_prefix character varying, oob_mark integer, oob_in character varying, oob_out character varying, oob_family integer, ip_saddr_str inet, ip_daddr_str inet, ip_protocol integer, ip_tos integer, ip_ttl integer, ip_totlen integer, ip_ihl integer, ip_csum integer, ip_id integer, ip_fragoff integer, label integer) RETURNS bigint
    LANGUAGE sql
    AS $_$

        INSERT INTO ulog2 (oob_time_sec,oob_time_usec,oob_hook,oob_prefix,oob_mark,

                        oob_in,oob_out,oob_family,ip_saddr_str,ip_daddr_str,ip_protocol,

                        ip_tos,ip_ttl,ip_totlen,ip_ihl,ip_csum,ip_id,ip_fragoff,label)

                VALUES ($1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14,$15,$16,$17,$18,$19);

        SELECT currval('ulog2__id_seq');

$_$;


ALTER FUNCTION public.insert_ip_packet_full(oob_time_sec integer, oob_time_usec integer, oob_hook integer, oob_prefix character varying, oob_mark integer, oob_in character varying, oob_out character varying, oob_family integer, ip_saddr_str inet, ip_daddr_str inet, ip_protocol integer, ip_tos integer, ip_ttl integer, ip_totlen integer, ip_ihl integer, ip_csum integer, ip_id integer, ip_fragoff integer, label integer) OWNER TO ulog2;

--
-- Name: insert_or_replace_ct(integer, inet, inet, integer, integer, integer, bigint, bigint, inet, inet, integer, integer, integer, bigint, bigint, integer, integer, bigint, bigint, bigint, bigint, bigint, integer); Type: FUNCTION; Schema: public; Owner: ulog2
--

CREATE FUNCTION insert_or_replace_ct(_oob_family integer, _orig_ip_saddr inet, _orig_ip_daddr inet, _orig_ip_protocol integer, _orig_l4_sport integer, _orig_l4_dport integer, _orig_raw_pktlen bigint, _orig_raw_pktcount bigint, _reply_ip_saddr inet, _reply_ip_daddr inet, _reply_ip_protocol integer, _reply_l4_sport integer, _reply_l4_dport integer, _reply_raw_pktlen bigint, _reply_raw_pktcount bigint, _icmp_code integer, _icmp_type integer, _ct_mark bigint, _flow_start_sec bigint, _flow_start_usec bigint, _flow_end_sec bigint, _flow_end_usec bigint, _ct_event integer) RETURNS bigint
    LANGUAGE plpgsql
    AS $_$

DECLARE

        _id bigint;

BEGIN

        IF (_ct_event = 4) THEN

          if (_orig_ip_protocol = 1) THEN

            UPDATE ulog2_ct SET (orig_raw_pktlen, orig_raw_pktcount,

                reply_raw_pktlen, reply_raw_pktcount,

                ct_mark, flow_end_sec, flow_end_usec, ct_event)

                = ($7,$8,$14,$15,$18,$21,$22,$23)

            WHERE oob_family=$1 AND orig_ip_saddr_str = $2

                AND orig_ip_daddr_str = $3 AND orig_ip_protocol = $4

                AND reply_ip_saddr_str = $9 AND reply_ip_daddr_str = $10

                AND reply_ip_protocol = $11

                AND icmp_code = $16 AND icmp_type = $17 

                AND ct_event < 4;

          ELSE

            UPDATE ulog2_ct SET (orig_raw_pktlen, orig_raw_pktcount,

                reply_raw_pktlen, reply_raw_pktcount,

                ct_mark, flow_end_sec, flow_end_usec, ct_event)

                = ($7,$8,$14,$15,$18,$21,$22,$23)

            WHERE oob_family=$1 AND orig_ip_saddr_str = $2

                AND orig_ip_daddr_str = $3 AND orig_ip_protocol = $4

                AND orig_l4_sport = $5 AND orig_l4_dport = $6

                AND reply_ip_saddr_str = $9 AND reply_ip_daddr_str = $10

                AND reply_ip_protocol = $11 AND reply_l4_sport = $12

                AND reply_l4_dport = $13 

                AND ct_event < 4;

          END IF;

        ELSE

          _id := INSERT_CT($1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14,$15,$16,$17,$18,$19,$20,$21,$22,$23);

        END IF;

        RETURN _id;

END

$_$;


ALTER FUNCTION public.insert_or_replace_ct(_oob_family integer, _orig_ip_saddr inet, _orig_ip_daddr inet, _orig_ip_protocol integer, _orig_l4_sport integer, _orig_l4_dport integer, _orig_raw_pktlen bigint, _orig_raw_pktcount bigint, _reply_ip_saddr inet, _reply_ip_daddr inet, _reply_ip_protocol integer, _reply_l4_sport integer, _reply_l4_dport integer, _reply_raw_pktlen bigint, _reply_raw_pktcount bigint, _icmp_code integer, _icmp_type integer, _ct_mark bigint, _flow_start_sec bigint, _flow_start_usec bigint, _flow_end_sec bigint, _flow_end_usec bigint, _ct_event integer) OWNER TO ulog2;

--
-- Name: insert_or_select_mac(macaddr, macaddr, integer); Type: FUNCTION; Schema: public; Owner: ulog2
--

CREATE FUNCTION insert_or_select_mac(in_mac_saddr macaddr, in_mac_daddr macaddr, in_mac_protocol integer) RETURNS bigint
    LANGUAGE plpgsql
    AS $_$

DECLARE

        _id bigint;

BEGIN

        IF $2 IS NULL THEN

                SELECT INTO _id _mac_id FROM mac WHERE mac_saddr = $1 AND mac_daddr IS NULL AND mac_protocol = $3;

        ELSE

                SELECT INTO _id _mac_id FROM mac WHERE mac_saddr = $1 AND mac_daddr = $2 AND mac_protocol = $3;

        END IF;

        IF NOT FOUND THEN

                INSERT INTO mac (mac_saddr,mac_daddr,mac_protocol) VALUES ($1,$2,$3) RETURNING _mac_id INTO _id;

                RETURN _id;

        END IF;

        RETURN _id;

END

$_$;


ALTER FUNCTION public.insert_or_select_mac(in_mac_saddr macaddr, in_mac_daddr macaddr, in_mac_protocol integer) OWNER TO ulog2;

--
-- Name: insert_packet_full(integer, integer, integer, character varying, integer, character varying, character varying, integer, inet, inet, integer, integer, integer, integer, integer, integer, integer, integer, integer, integer, bigint, bigint, integer, boolean, integer, boolean, boolean, boolean, boolean, boolean, integer, integer, integer, integer, integer, integer, integer, integer, integer, integer, integer, integer, integer, integer, integer, character varying, character varying, character varying, integer, integer, integer, integer, integer); Type: FUNCTION; Schema: public; Owner: ulog2
--

CREATE FUNCTION insert_packet_full(oob_time_sec integer, oob_time_usec integer, oob_hook integer, oob_prefix character varying, oob_mark integer, oob_in character varying, oob_out character varying, oob_family integer, ip_saddr_str inet, ip_daddr_str inet, ip_protocol integer, ip_tos integer, ip_ttl integer, ip_totlen integer, ip_ihl integer, ip_csum integer, ip_id integer, ip_fragoff integer, tcp_sport integer, tcp_dport integer, tcp_seq bigint, tcp_ackseq bigint, tcp_window integer, tcp_urg boolean, tcp_urgp integer, tcp_ack boolean, tcp_psh boolean, tcp_rst boolean, tcp_syn boolean, tcp_fin boolean, udp_sport integer, udp_dport integer, udp_len integer, icmp_type integer, icmp_code integer, icmp_echoid integer, icmp_echoseq integer, icmp_gateway integer, icmp_fragmtu integer, icmpv6_type integer, icmpv6_code integer, icmpv6_echoid integer, icmpv6_echoseq integer, icmpv6_csum integer, raw_type integer, raw_header character varying, mac_saddr character varying, mac_daddr character varying, mac_protocol integer, label integer, sctp_sport integer, sctp_dport integer, sctp_csum integer) RETURNS bigint
    LANGUAGE plpgsql
    AS $_$

DECLARE

        t_id bigint;

        t_mac_id bigint;

BEGIN

        t_id := INSERT_IP_PACKET_FULL($1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14,$15,$16,$17,$18,$50);

        IF (ip_protocol = 6) THEN

                PERFORM INSERT_TCP_FULL(t_id,$19,$20,$21,$22,$23,$24,$25,$26,$27,$28,$29,$30);

        ELSIF (ip_protocol = 17) THEN

                PERFORM INSERT_UDP(t_id,$31,$32,$33);

        ELSIF (ip_protocol = 132) THEN

                PERFORM INSERT_SCTP(t_id,$51,$52,$53);

        ELSIF (ip_protocol = 1) THEN

                PERFORM INSERT_ICMP(t_id,$34,$35,$36,$37,$38,$39);

        ELSIF (ip_protocol = 58) THEN

                PERFORM INSERT_ICMPV6(t_id,$40,$41,$42,$43,$44);

        END IF;

        IF (raw_type = 1) THEN

                t_mac_id = INSERT_OR_SELECT_MAC($47::macaddr,$48::macaddr,$49);

                UPDATE ulog2 SET mac_id = t_mac_id WHERE _id = t_id;

        ELSE

                PERFORM INSERT_HARDWARE_HEADER(t_id,$45,$46);

        END IF;

        RETURN t_id;

END

$_$;


ALTER FUNCTION public.insert_packet_full(oob_time_sec integer, oob_time_usec integer, oob_hook integer, oob_prefix character varying, oob_mark integer, oob_in character varying, oob_out character varying, oob_family integer, ip_saddr_str inet, ip_daddr_str inet, ip_protocol integer, ip_tos integer, ip_ttl integer, ip_totlen integer, ip_ihl integer, ip_csum integer, ip_id integer, ip_fragoff integer, tcp_sport integer, tcp_dport integer, tcp_seq bigint, tcp_ackseq bigint, tcp_window integer, tcp_urg boolean, tcp_urgp integer, tcp_ack boolean, tcp_psh boolean, tcp_rst boolean, tcp_syn boolean, tcp_fin boolean, udp_sport integer, udp_dport integer, udp_len integer, icmp_type integer, icmp_code integer, icmp_echoid integer, icmp_echoseq integer, icmp_gateway integer, icmp_fragmtu integer, icmpv6_type integer, icmpv6_code integer, icmpv6_echoid integer, icmpv6_echoseq integer, icmpv6_csum integer, raw_type integer, raw_header character varying, mac_saddr character varying, mac_daddr character varying, mac_protocol integer, label integer, sctp_sport integer, sctp_dport integer, sctp_csum integer) OWNER TO ulog2;

--
-- Name: insert_sctp(bigint, integer, integer, integer); Type: FUNCTION; Schema: public; Owner: ulog2
--

CREATE FUNCTION insert_sctp(sctp_id bigint, sctp_sport integer, sctp_dport integer, sctp_csum integer) RETURNS bigint
    LANGUAGE sql
    AS $_$

        INSERT INTO sctp (_sctp_id,sctp_sport,sctp_dport,sctp_csum)

                VALUES ($1,$2,$3,$4);

        SELECT currval('ulog2__id_seq');

$_$;


ALTER FUNCTION public.insert_sctp(sctp_id bigint, sctp_sport integer, sctp_dport integer, sctp_csum integer) OWNER TO ulog2;

--
-- Name: insert_tcp_full(bigint, integer, integer, bigint, bigint, integer, boolean, integer, boolean, boolean, boolean, boolean, boolean); Type: FUNCTION; Schema: public; Owner: ulog2
--

CREATE FUNCTION insert_tcp_full(tcp_id bigint, tcp_sport integer, tcp_dport integer, tcp_seq bigint, tcp_ackseq bigint, tcp_window integer, tcp_urg boolean, tcp_urgp integer, tcp_ack boolean, tcp_psh boolean, tcp_rst boolean, tcp_syn boolean, tcp_fin boolean) RETURNS bigint
    LANGUAGE sql
    AS $_$

        INSERT INTO tcp (_tcp_id,tcp_sport,tcp_dport,tcp_seq,tcp_ackseq,tcp_window,tcp_urg,

                        tcp_urgp,tcp_ack,tcp_psh,tcp_rst,tcp_syn,tcp_fin)

                VALUES ($1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13);

        SELECT currval('ulog2__id_seq');

$_$;


ALTER FUNCTION public.insert_tcp_full(tcp_id bigint, tcp_sport integer, tcp_dport integer, tcp_seq bigint, tcp_ackseq bigint, tcp_window integer, tcp_urg boolean, tcp_urgp integer, tcp_ack boolean, tcp_psh boolean, tcp_rst boolean, tcp_syn boolean, tcp_fin boolean) OWNER TO ulog2;

--
-- Name: insert_udp(bigint, integer, integer, integer); Type: FUNCTION; Schema: public; Owner: ulog2
--

CREATE FUNCTION insert_udp(udp_id bigint, udp_sport integer, udp_dport integer, udp_len integer) RETURNS bigint
    LANGUAGE sql
    AS $_$

        INSERT INTO udp (_udp_id,udp_sport,udp_dport,udp_len)

                VALUES ($1,$2,$3,$4);

        SELECT currval('ulog2__id_seq');

$_$;


ALTER FUNCTION public.insert_udp(udp_id bigint, udp_sport integer, udp_dport integer, udp_len integer) OWNER TO ulog2;

--
-- Name: ulog2_add_foreign_keys(); Type: FUNCTION; Schema: public; Owner: ulog2
--

CREATE FUNCTION ulog2_add_foreign_keys() RETURNS void
    LANGUAGE sql
    AS $$

  ALTER TABLE tcp  ADD CONSTRAINT tcp_id_fk  FOREIGN KEY (_tcp_id)  REFERENCES ulog2(_id);

  ALTER TABLE udp  ADD CONSTRAINT udp_id_fk  FOREIGN KEY (_udp_id)  REFERENCES ulog2(_id);

  ALTER TABLE sctp  ADD CONSTRAINT sctp_id_fk  FOREIGN KEY (_sctp_id)  REFERENCES ulog2(_id);

  ALTER TABLE icmp ADD CONSTRAINT icmp_id_fk FOREIGN KEY (_icmp_id) REFERENCES ulog2(_id);

  ALTER TABLE icmpv6 ADD CONSTRAINT icmpv6_id_fk FOREIGN KEY (_icmpv6_id) REFERENCES ulog2(_id);

  ALTER TABLE ulog2 ADD CONSTRAINT mac_id_fk FOREIGN KEY (mac_id) REFERENCES mac(_mac_id);

$$;


ALTER FUNCTION public.ulog2_add_foreign_keys() OWNER TO ulog2;

--
-- Name: ulog2_drop_foreign_keys(); Type: FUNCTION; Schema: public; Owner: ulog2
--

CREATE FUNCTION ulog2_drop_foreign_keys() RETURNS void
    LANGUAGE sql
    AS $$

  ALTER TABLE ulog2 DROP CONSTRAINT mac_id_fk;

  ALTER TABLE icmpv6 DROP CONSTRAINT icmpv6_id_fk;

  ALTER TABLE icmp DROP CONSTRAINT icmp_id_fk;

  ALTER TABLE udp  DROP CONSTRAINT udp_id_fk;

  ALTER TABLE tcp  DROP CONSTRAINT tcp_id_fk;

$$;


ALTER FUNCTION public.ulog2_drop_foreign_keys() OWNER TO ulog2;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: _extensions; Type: TABLE; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE TABLE _extensions (
    ext_id integer NOT NULL,
    ext_name character varying(64) NOT NULL,
    table_name character varying(64) NOT NULL,
    join_name character varying(64) NOT NULL
);


ALTER TABLE public._extensions OWNER TO ulog2;

--
-- Name: _extensions_ext_id_seq; Type: SEQUENCE; Schema: public; Owner: ulog2
--

CREATE SEQUENCE _extensions_ext_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public._extensions_ext_id_seq OWNER TO ulog2;

--
-- Name: _extensions_ext_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: ulog2
--

ALTER SEQUENCE _extensions_ext_id_seq OWNED BY _extensions.ext_id;


--
-- Name: _format; Type: TABLE; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE TABLE _format (
    version integer
);


ALTER TABLE public._format OWNER TO ulog2;

--
-- Name: ulog2_ct__ct_id_seq; Type: SEQUENCE; Schema: public; Owner: ulog2
--

CREATE SEQUENCE ulog2_ct__ct_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.ulog2_ct__ct_id_seq OWNER TO ulog2;

--
-- Name: ulog2_ct; Type: TABLE; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE TABLE ulog2_ct (
    _ct_id bigint DEFAULT nextval('ulog2_ct__ct_id_seq'::regclass) NOT NULL,
    oob_family smallint,
    orig_ip_saddr_str inet,
    orig_ip_daddr_str inet,
    orig_ip_protocol smallint,
    orig_l4_sport integer,
    orig_l4_dport integer,
    orig_raw_pktlen bigint DEFAULT 0,
    orig_raw_pktcount bigint DEFAULT 0,
    reply_ip_saddr_str inet,
    reply_ip_daddr_str inet,
    reply_ip_protocol smallint,
    reply_l4_sport integer,
    reply_l4_dport integer,
    reply_raw_pktlen bigint DEFAULT 0,
    reply_raw_pktcount bigint DEFAULT 0,
    icmp_code smallint,
    icmp_type smallint,
    ct_mark bigint DEFAULT 0,
    flow_start_sec bigint DEFAULT 0,
    flow_start_usec bigint DEFAULT 0,
    flow_end_sec bigint DEFAULT 0,
    flow_end_usec bigint DEFAULT 0,
    ct_event smallint DEFAULT 0
);


ALTER TABLE public.ulog2_ct OWNER TO ulog2;

--
-- Name: conntrack; Type: VIEW; Schema: public; Owner: ulog2
--

CREATE VIEW conntrack AS
    SELECT ulog2_ct.oob_family, ulog2_ct.flow_end_sec, ulog2_ct.flow_end_usec, ulog2_ct.orig_l4_dport, ulog2_ct.orig_l4_sport, ulog2_ct.flow_start_sec, ulog2_ct.reply_l4_dport, ulog2_ct.reply_l4_sport, ulog2_ct.flow_start_usec, ulog2_ct.orig_raw_pktlen, ulog2_ct.orig_ip_protocol, ulog2_ct.reply_raw_pktlen, ulog2_ct.orig_ip_daddr_str, ulog2_ct.orig_ip_saddr_str, ulog2_ct.orig_raw_pktcount, ulog2_ct.reply_ip_protocol, ulog2_ct.reply_ip_daddr_str, ulog2_ct.reply_ip_saddr_str, ulog2_ct.reply_raw_pktcount, ulog2_ct._ct_id, ulog2_ct.ct_mark, ulog2_ct.ct_event, ulog2_ct.icmp_code, ulog2_ct.icmp_type FROM ulog2_ct WHERE (((ulog2_ct.ct_event <> (4)::smallint) AND (ulog2_ct.orig_ip_protocol <> 58)) AND ((ulog2_ct.flow_start_sec)::double precision > (SELECT date_part('epoch'::text, (SELECT (now() - '24:00:00'::interval) AS now)) AS date_part)));


ALTER TABLE public.conntrack OWNER TO ulog2;

--
-- Name: VIEW conntrack; Type: COMMENT; Schema: public; Owner: ulog2
--

COMMENT ON VIEW conntrack IS 'Alle activen verbindungen';


--
-- Name: hwhdr; Type: TABLE; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE TABLE hwhdr (
    _hw_id bigint NOT NULL,
    raw_type integer,
    raw_header character varying(256) DEFAULT NULL::character varying
);


ALTER TABLE public.hwhdr OWNER TO ulog2;

--
-- Name: icmp; Type: TABLE; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE TABLE icmp (
    _icmp_id bigint NOT NULL,
    icmp_type smallint,
    icmp_code smallint,
    icmp_echoid integer,
    icmp_echoseq integer,
    icmp_gateway integer,
    icmp_fragmtu smallint
);


ALTER TABLE public.icmp OWNER TO ulog2;

--
-- Name: icmpv6; Type: TABLE; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE TABLE icmpv6 (
    _icmpv6_id bigint NOT NULL,
    icmpv6_type smallint,
    icmpv6_code smallint,
    icmpv6_echoid integer,
    icmpv6_echoseq integer,
    icmpv6_csum integer
);


ALTER TABLE public.icmpv6 OWNER TO ulog2;

--
-- Name: ip_proto; Type: TABLE; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE TABLE ip_proto (
    _proto_id integer NOT NULL,
    proto_name character varying(16) DEFAULT NULL::character varying,
    proto_desc character varying(255) DEFAULT NULL::character varying
);


ALTER TABLE public.ip_proto OWNER TO ulog2;

--
-- Name: ip_proto__proto_id_seq; Type: SEQUENCE; Schema: public; Owner: ulog2
--

CREATE SEQUENCE ip_proto__proto_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.ip_proto__proto_id_seq OWNER TO ulog2;

--
-- Name: ip_proto__proto_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: ulog2
--

ALTER SEQUENCE ip_proto__proto_id_seq OWNED BY ip_proto._proto_id;


--
-- Name: lfnet-meta; Type: TABLE; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE TABLE "lfnet-meta" (
    version character varying(1024)
);


ALTER TABLE public."lfnet-meta" OWNER TO ulog2;

--
-- Name: TABLE "lfnet-meta"; Type: COMMENT; Schema: public; Owner: ulog2
--

COMMENT ON TABLE "lfnet-meta" IS 'Version Tracking';


--
-- Name: mac__id_seq; Type: SEQUENCE; Schema: public; Owner: ulog2
--

CREATE SEQUENCE mac__id_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.mac__id_seq OWNER TO ulog2;

--
-- Name: mac; Type: TABLE; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE TABLE mac (
    _mac_id bigint DEFAULT nextval('mac__id_seq'::regclass) NOT NULL,
    mac_saddr macaddr NOT NULL,
    mac_daddr macaddr,
    mac_protocol integer
);


ALTER TABLE public.mac OWNER TO ulog2;

--
-- Name: nufw; Type: TABLE; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE TABLE nufw (
    _nufw_id bigint NOT NULL,
    username character varying(30) DEFAULT NULL::character varying,
    user_id integer,
    client_os character varying(100) DEFAULT NULL::character varying,
    client_app character varying(256) DEFAULT NULL::character varying
);


ALTER TABLE public.nufw OWNER TO ulog2;

--
-- Name: sctp; Type: TABLE; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE TABLE sctp (
    _sctp_id bigint NOT NULL,
    sctp_sport integer,
    sctp_dport integer,
    sctp_csum smallint
);


ALTER TABLE public.sctp OWNER TO ulog2;

--
-- Name: tcp; Type: TABLE; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE TABLE tcp (
    _tcp_id bigint NOT NULL,
    tcp_sport integer,
    tcp_dport integer,
    tcp_seq bigint,
    tcp_ackseq bigint,
    tcp_window integer,
    tcp_urg boolean,
    tcp_urgp integer,
    tcp_ack boolean,
    tcp_psh boolean,
    tcp_rst boolean,
    tcp_syn boolean,
    tcp_fin boolean
);


ALTER TABLE public.tcp OWNER TO ulog2;

--
-- Name: udp; Type: TABLE; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE TABLE udp (
    _udp_id bigint NOT NULL,
    udp_sport integer,
    udp_dport integer,
    udp_len smallint
);


ALTER TABLE public.udp OWNER TO ulog2;

--
-- Name: ulog2__id_seq; Type: SEQUENCE; Schema: public; Owner: ulog2
--

CREATE SEQUENCE ulog2__id_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.ulog2__id_seq OWNER TO ulog2;

--
-- Name: ulog2; Type: TABLE; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE TABLE ulog2 (
    _id bigint DEFAULT nextval('ulog2__id_seq'::regclass) NOT NULL,
    oob_time_sec integer,
    oob_time_usec integer,
    oob_hook smallint,
    oob_prefix character varying(32) DEFAULT NULL::character varying,
    oob_mark integer,
    oob_in character varying(32) DEFAULT NULL::character varying,
    oob_out character varying(32) DEFAULT NULL::character varying,
    oob_family smallint,
    ip_saddr_str inet,
    ip_daddr_str inet,
    ip_protocol smallint,
    ip_tos smallint,
    ip_ttl smallint,
    ip_totlen smallint,
    ip_ihl smallint,
    ip_csum integer,
    ip_id integer,
    ip_fragoff smallint,
    label smallint,
    mac_id bigint,
    "timestamp" timestamp without time zone DEFAULT '2009-11-15 21:00:17.833973'::timestamp without time zone NOT NULL
);


ALTER TABLE public.ulog2 OWNER TO ulog2;

--
-- Name: ulog; Type: VIEW; Schema: public; Owner: ulog2
--

CREATE VIEW ulog AS
    SELECT ulog2._id, ulog2.oob_time_sec, ulog2.oob_time_usec, ulog2.oob_hook, ulog2.oob_prefix, ulog2.oob_mark, ulog2.oob_in, ulog2.oob_out, ulog2.oob_family, ulog2.ip_saddr_str, ulog2.ip_daddr_str, ulog2.ip_protocol, ulog2.ip_tos, ulog2.ip_ttl, ulog2.ip_totlen, ulog2.ip_ihl, ulog2.ip_csum, ulog2.ip_id, ulog2.ip_fragoff, tcp.tcp_sport, tcp.tcp_dport, tcp.tcp_seq, tcp.tcp_ackseq, tcp.tcp_window, tcp.tcp_urg, tcp.tcp_urgp, tcp.tcp_ack, tcp.tcp_psh, tcp.tcp_rst, tcp.tcp_syn, tcp.tcp_fin, udp.udp_sport, udp.udp_dport, udp.udp_len, icmp.icmp_type, icmp.icmp_code, icmp.icmp_echoid, icmp.icmp_echoseq, icmp.icmp_gateway, icmp.icmp_fragmtu, icmpv6.icmpv6_type, icmpv6.icmpv6_code, icmpv6.icmpv6_echoid, icmpv6.icmpv6_echoseq, icmpv6.icmpv6_csum, hwhdr.raw_type, hwhdr.raw_header AS mac_str, mac.mac_saddr AS mac_saddr_str, mac.mac_daddr AS mac_daddr_str, mac.mac_protocol AS oob_protocol, ulog2.label AS raw_label, sctp.sctp_sport, sctp.sctp_dport, sctp.sctp_csum FROM (((((((ulog2 LEFT JOIN tcp ON ((ulog2._id = tcp._tcp_id))) LEFT JOIN udp ON ((ulog2._id = udp._udp_id))) LEFT JOIN sctp ON ((ulog2._id = sctp._sctp_id))) LEFT JOIN icmp ON ((ulog2._id = icmp._icmp_id))) LEFT JOIN mac ON ((ulog2.mac_id = mac._mac_id))) LEFT JOIN hwhdr ON ((ulog2._id = hwhdr._hw_id))) LEFT JOIN icmpv6 ON ((ulog2._id = icmpv6._icmpv6_id))) WHERE ((ulog2.oob_time_sec)::double precision > (SELECT date_part('epoch'::text, (SELECT (now() - '24:00:00'::interval) AS now)) AS date_part));


ALTER TABLE public.ulog OWNER TO ulog2;

--
-- Name: view_icmp; Type: VIEW; Schema: public; Owner: ulog2
--

CREATE VIEW view_icmp AS
    SELECT ulog2._id, ulog2.oob_time_sec, ulog2.oob_time_usec, ulog2.oob_hook, ulog2.oob_prefix, ulog2.oob_mark, ulog2.oob_in, ulog2.oob_out, ulog2.oob_family, ulog2.ip_saddr_str, ulog2.ip_daddr_str, ulog2.ip_protocol, ulog2.ip_tos, ulog2.ip_ttl, ulog2.ip_totlen, ulog2.ip_ihl, ulog2.ip_csum, ulog2.ip_id, ulog2.ip_fragoff, ulog2.label, ulog2.mac_id, ulog2."timestamp", icmp._icmp_id, icmp.icmp_type, icmp.icmp_code, icmp.icmp_echoid, icmp.icmp_echoseq, icmp.icmp_gateway, icmp.icmp_fragmtu FROM (ulog2 JOIN icmp ON ((ulog2._id = icmp._icmp_id)));


ALTER TABLE public.view_icmp OWNER TO ulog2;

--
-- Name: view_icmpv6; Type: VIEW; Schema: public; Owner: ulog2
--

CREATE VIEW view_icmpv6 AS
    SELECT ulog2._id, ulog2.oob_time_sec, ulog2.oob_time_usec, ulog2.oob_hook, ulog2.oob_prefix, ulog2.oob_mark, ulog2.oob_in, ulog2.oob_out, ulog2.oob_family, ulog2.ip_saddr_str, ulog2.ip_daddr_str, ulog2.ip_protocol, ulog2.ip_tos, ulog2.ip_ttl, ulog2.ip_totlen, ulog2.ip_ihl, ulog2.ip_csum, ulog2.ip_id, ulog2.ip_fragoff, ulog2.label, ulog2.mac_id, ulog2."timestamp", icmpv6._icmpv6_id, icmpv6.icmpv6_type, icmpv6.icmpv6_code, icmpv6.icmpv6_echoid, icmpv6.icmpv6_echoseq, icmpv6.icmpv6_csum FROM (ulog2 JOIN icmpv6 ON ((ulog2._id = icmpv6._icmpv6_id)));


ALTER TABLE public.view_icmpv6 OWNER TO ulog2;

--
-- Name: view_nufw; Type: VIEW; Schema: public; Owner: ulog2
--

CREATE VIEW view_nufw AS
    SELECT ulog2._id, ulog2.oob_time_sec, ulog2.oob_time_usec, ulog2.oob_hook, ulog2.oob_prefix, ulog2.oob_mark, ulog2.oob_in, ulog2.oob_out, ulog2.oob_family, ulog2.ip_saddr_str, ulog2.ip_daddr_str, ulog2.ip_protocol, ulog2.ip_tos, ulog2.ip_ttl, ulog2.ip_totlen, ulog2.ip_ihl, ulog2.ip_csum, ulog2.ip_id, ulog2.ip_fragoff, ulog2.label, ulog2.mac_id, ulog2."timestamp", nufw._nufw_id, nufw.username, nufw.user_id, nufw.client_os, nufw.client_app FROM (ulog2 JOIN nufw ON ((ulog2._id = nufw._nufw_id)));


ALTER TABLE public.view_nufw OWNER TO ulog2;

--
-- Name: view_tcp; Type: VIEW; Schema: public; Owner: ulog2
--

CREATE VIEW view_tcp AS
    SELECT ulog2._id, ulog2.oob_time_sec, ulog2.oob_time_usec, ulog2.oob_hook, ulog2.oob_prefix, ulog2.oob_mark, ulog2.oob_in, ulog2.oob_out, ulog2.oob_family, ulog2.ip_saddr_str, ulog2.ip_daddr_str, ulog2.ip_protocol, ulog2.ip_tos, ulog2.ip_ttl, ulog2.ip_totlen, ulog2.ip_ihl, ulog2.ip_csum, ulog2.ip_id, ulog2.ip_fragoff, ulog2.label, ulog2.mac_id, ulog2."timestamp", tcp._tcp_id, tcp.tcp_sport, tcp.tcp_dport, tcp.tcp_seq, tcp.tcp_ackseq, tcp.tcp_window, tcp.tcp_urg, tcp.tcp_urgp, tcp.tcp_ack, tcp.tcp_psh, tcp.tcp_rst, tcp.tcp_syn, tcp.tcp_fin FROM (ulog2 JOIN tcp ON ((ulog2._id = tcp._tcp_id)));


ALTER TABLE public.view_tcp OWNER TO ulog2;

--
-- Name: view_tcp_quad; Type: VIEW; Schema: public; Owner: ulog2
--

CREATE VIEW view_tcp_quad AS
    SELECT ulog2._id, ulog2.ip_saddr_str, tcp.tcp_sport, ulog2.ip_daddr_str, tcp.tcp_dport FROM (ulog2 JOIN tcp ON ((ulog2._id = tcp._tcp_id)));


ALTER TABLE public.view_tcp_quad OWNER TO ulog2;

--
-- Name: view_udp; Type: VIEW; Schema: public; Owner: ulog2
--

CREATE VIEW view_udp AS
    SELECT ulog2._id, ulog2.oob_time_sec, ulog2.oob_time_usec, ulog2.oob_hook, ulog2.oob_prefix, ulog2.oob_mark, ulog2.oob_in, ulog2.oob_out, ulog2.oob_family, ulog2.ip_saddr_str, ulog2.ip_daddr_str, ulog2.ip_protocol, ulog2.ip_tos, ulog2.ip_ttl, ulog2.ip_totlen, ulog2.ip_ihl, ulog2.ip_csum, ulog2.ip_id, ulog2.ip_fragoff, ulog2.label, ulog2.mac_id, ulog2."timestamp", udp._udp_id, udp.udp_sport, udp.udp_dport, udp.udp_len FROM (ulog2 JOIN udp ON ((ulog2._id = udp._udp_id)));


ALTER TABLE public.view_udp OWNER TO ulog2;

--
-- Name: view_udp_quad; Type: VIEW; Schema: public; Owner: ulog2
--

CREATE VIEW view_udp_quad AS
    SELECT ulog2._id, ulog2.ip_saddr_str, udp.udp_sport, ulog2.ip_daddr_str, udp.udp_dport FROM (ulog2 JOIN udp ON ((ulog2._id = udp._udp_id)));


ALTER TABLE public.view_udp_quad OWNER TO ulog2;

--
-- Name: ext_id; Type: DEFAULT; Schema: public; Owner: ulog2
--

ALTER TABLE _extensions ALTER COLUMN ext_id SET DEFAULT nextval('_extensions_ext_id_seq'::regclass);


--
-- Name: _proto_id; Type: DEFAULT; Schema: public; Owner: ulog2
--

ALTER TABLE ip_proto ALTER COLUMN _proto_id SET DEFAULT nextval('ip_proto__proto_id_seq'::regclass);


--
-- Name: _extensions_pkey; Type: CONSTRAINT; Schema: public; Owner: ulog2; Tablespace: 
--

ALTER TABLE ONLY _extensions
    ADD CONSTRAINT _extensions_pkey PRIMARY KEY (ext_id);


--
-- Name: hwhdr_pkey; Type: CONSTRAINT; Schema: public; Owner: ulog2; Tablespace: 
--

ALTER TABLE ONLY hwhdr
    ADD CONSTRAINT hwhdr_pkey PRIMARY KEY (_hw_id);


--
-- Name: icmp_pkey; Type: CONSTRAINT; Schema: public; Owner: ulog2; Tablespace: 
--

ALTER TABLE ONLY icmp
    ADD CONSTRAINT icmp_pkey PRIMARY KEY (_icmp_id);


--
-- Name: icmpv6_pkey; Type: CONSTRAINT; Schema: public; Owner: ulog2; Tablespace: 
--

ALTER TABLE ONLY icmpv6
    ADD CONSTRAINT icmpv6_pkey PRIMARY KEY (_icmpv6_id);


--
-- Name: ip_proto_pkey; Type: CONSTRAINT; Schema: public; Owner: ulog2; Tablespace: 
--

ALTER TABLE ONLY ip_proto
    ADD CONSTRAINT ip_proto_pkey PRIMARY KEY (_proto_id);


--
-- Name: mac_pkey; Type: CONSTRAINT; Schema: public; Owner: ulog2; Tablespace: 
--

ALTER TABLE ONLY mac
    ADD CONSTRAINT mac_pkey PRIMARY KEY (_mac_id);


--
-- Name: nufw_pkey; Type: CONSTRAINT; Schema: public; Owner: ulog2; Tablespace: 
--

ALTER TABLE ONLY nufw
    ADD CONSTRAINT nufw_pkey PRIMARY KEY (_nufw_id);


--
-- Name: sctp_pkey; Type: CONSTRAINT; Schema: public; Owner: ulog2; Tablespace: 
--

ALTER TABLE ONLY sctp
    ADD CONSTRAINT sctp_pkey PRIMARY KEY (_sctp_id);


--
-- Name: tcp_pkey; Type: CONSTRAINT; Schema: public; Owner: ulog2; Tablespace: 
--

ALTER TABLE ONLY tcp
    ADD CONSTRAINT tcp_pkey PRIMARY KEY (_tcp_id);


--
-- Name: udp_pkey; Type: CONSTRAINT; Schema: public; Owner: ulog2; Tablespace: 
--

ALTER TABLE ONLY udp
    ADD CONSTRAINT udp_pkey PRIMARY KEY (_udp_id);


--
-- Name: ulog2_ct_pkey; Type: CONSTRAINT; Schema: public; Owner: ulog2; Tablespace: 
--

ALTER TABLE ONLY ulog2_ct
    ADD CONSTRAINT ulog2_ct_pkey PRIMARY KEY (_ct_id);


--
-- Name: ulog2_pkey; Type: CONSTRAINT; Schema: public; Owner: ulog2; Tablespace: 
--

ALTER TABLE ONLY ulog2
    ADD CONSTRAINT ulog2_pkey PRIMARY KEY (_id);


--
-- Name: mac_daddr; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX mac_daddr ON mac USING btree (mac_daddr);


--
-- Name: mac_saddr; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX mac_saddr ON mac USING btree (mac_saddr);


--
-- Name: nufw_user_id; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX nufw_user_id ON nufw USING btree (user_id);


--
-- Name: raw_header; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX raw_header ON hwhdr USING btree (raw_header);


--
-- Name: raw_type; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX raw_type ON hwhdr USING btree (raw_type);


--
-- Name: sctp_dport; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX sctp_dport ON sctp USING btree (sctp_dport);


--
-- Name: sctp_sport; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX sctp_sport ON sctp USING btree (sctp_sport);


--
-- Name: tcp_dport; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX tcp_dport ON tcp USING btree (tcp_dport);


--
-- Name: tcp_sport; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX tcp_sport ON tcp USING btree (tcp_sport);


--
-- Name: udp_dport; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX udp_dport ON udp USING btree (udp_dport);


--
-- Name: udp_sport; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX udp_sport ON udp USING btree (udp_sport);


--
-- Name: ulog2_ct_event; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX ulog2_ct_event ON ulog2_ct USING btree (ct_event);


--
-- Name: ulog2_ct_oob_family; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX ulog2_ct_oob_family ON ulog2_ct USING btree (oob_family);


--
-- Name: ulog2_ct_orig_ip_daddr; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX ulog2_ct_orig_ip_daddr ON ulog2_ct USING btree (orig_ip_daddr_str);


--
-- Name: ulog2_ct_orig_ip_saddr; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX ulog2_ct_orig_ip_saddr ON ulog2_ct USING btree (orig_ip_saddr_str);


--
-- Name: ulog2_ct_orig_l4_dport; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX ulog2_ct_orig_l4_dport ON ulog2_ct USING btree (orig_l4_dport);


--
-- Name: ulog2_ct_orig_l4_sport; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX ulog2_ct_orig_l4_sport ON ulog2_ct USING btree (orig_l4_sport);


--
-- Name: ulog2_ct_reply_ip_daddr; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX ulog2_ct_reply_ip_daddr ON ulog2_ct USING btree (reply_ip_daddr_str);


--
-- Name: ulog2_ct_reply_ip_saddr; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX ulog2_ct_reply_ip_saddr ON ulog2_ct USING btree (reply_ip_saddr_str);


--
-- Name: ulog2_ct_reply_l4_dport; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX ulog2_ct_reply_l4_dport ON ulog2_ct USING btree (reply_l4_dport);


--
-- Name: ulog2_ct_reply_l4_sport; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX ulog2_ct_reply_l4_sport ON ulog2_ct USING btree (reply_l4_sport);


--
-- Name: ulog2_ip_daddr; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX ulog2_ip_daddr ON ulog2 USING btree (ip_daddr_str);


--
-- Name: ulog2_ip_saddr; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX ulog2_ip_saddr ON ulog2 USING btree (ip_saddr_str);


--
-- Name: ulog2_oob_family; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX ulog2_oob_family ON ulog2 USING btree (oob_family);


--
-- Name: ulog2_timestamp; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE INDEX ulog2_timestamp ON ulog2 USING btree ("timestamp");


--
-- Name: unique_mac; Type: INDEX; Schema: public; Owner: ulog2; Tablespace: 
--

CREATE UNIQUE INDEX unique_mac ON mac USING btree (mac_saddr, mac_daddr, mac_protocol);


--
-- Name: icmp_id_fk; Type: FK CONSTRAINT; Schema: public; Owner: ulog2
--

ALTER TABLE ONLY icmp
    ADD CONSTRAINT icmp_id_fk FOREIGN KEY (_icmp_id) REFERENCES ulog2(_id);


--
-- Name: icmpv6_id_fk; Type: FK CONSTRAINT; Schema: public; Owner: ulog2
--

ALTER TABLE ONLY icmpv6
    ADD CONSTRAINT icmpv6_id_fk FOREIGN KEY (_icmpv6_id) REFERENCES ulog2(_id);


--
-- Name: mac_id_fk; Type: FK CONSTRAINT; Schema: public; Owner: ulog2
--

ALTER TABLE ONLY ulog2
    ADD CONSTRAINT mac_id_fk FOREIGN KEY (mac_id) REFERENCES mac(_mac_id);


--
-- Name: nufw_id_fk; Type: FK CONSTRAINT; Schema: public; Owner: ulog2
--

ALTER TABLE ONLY nufw
    ADD CONSTRAINT nufw_id_fk FOREIGN KEY (_nufw_id) REFERENCES ulog2(_id);


--
-- Name: sctp_id_fk; Type: FK CONSTRAINT; Schema: public; Owner: ulog2
--

ALTER TABLE ONLY sctp
    ADD CONSTRAINT sctp_id_fk FOREIGN KEY (_sctp_id) REFERENCES ulog2(_id);


--
-- Name: tcp_id_fk; Type: FK CONSTRAINT; Schema: public; Owner: ulog2
--

ALTER TABLE ONLY tcp
    ADD CONSTRAINT tcp_id_fk FOREIGN KEY (_tcp_id) REFERENCES ulog2(_id);


--
-- Name: udp_id_fk; Type: FK CONSTRAINT; Schema: public; Owner: ulog2
--

ALTER TABLE ONLY udp
    ADD CONSTRAINT udp_id_fk FOREIGN KEY (_udp_id) REFERENCES ulog2(_id);


--
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM postgres;
GRANT ALL ON SCHEMA public TO postgres;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
-- PostgreSQL database dump complete
--

