<?php
  /**
   *
   * DB-Connection und Helper Funktionen
   *
   * @version $Id: database.php,v 1.2 2010/04/09 14:55:31 jg Exp $
   * @package osfw
   * @author  <webdev@LF.net>
   * @copyright 2010, LF.net
   *
   */

  /**
   *
   * Datenbank Klasse, bei Bedarf fuer versch. DBs ableiten
   *
   * fluent interface, Aufrufe koennen verkettet werden
   * 
   * $db = new osfwDB($db_conf);
   * 
   * $db2 = new osfwDB();
   * $db2->setConfig($db_conf)->connect();
   *
   */
class osfwDB {
	
  /**
   *
   * Config fuer den DB-Connect
   * @var array
   * @access protected
   *
   */
  protected $config = false;
	
  /**
   *
   * Datenbank Verbindung
   * @var resource
   * @access protected
   *
   */
  protected $db = false;
	
	
  /**
   *
   * Konstruktor, initialisiert die DB
   *
   * @param array $config
   * @return void
   * @access public
   *
   */
  public function __construct($config = false) {

    if ($config) {
      $this->setConfig($config);
      $this->connect();
    }

  } // End function __construct

  /**
   *
   * Pruefen und setzen der Configs fuer den Connect
   *
   * @param array $config
   * @return object
   * @access public
   *
   */
  public function setConfig($config) {
	
    if (is_array($config)
	&& isset($config['db'])
	&& isset($config['user'])
	&& isset($config['pass'])
	&& isset($config['host'])) {
      $this->config = $config;
      return $this;
    }
		
    throw new BadMethodCallException('DB config is not valid');
		
		
  } // End function setConfig


  /**
   *
   * Baut die Verbindung zur DB auf falls noch nicht geschehen
   *
   * @return object
   * @access public
   *
   */
  public function connect() {
		
    if (! $this->db) {
      if (! $this->config) {
	throw new BadMethodCallException('DB config not found');
      }

      $dsn = 'dbname=' . $this->config['db'] . ' ' 
	. 'user=' . $this->config['user'] . ' '
	. 'host=' . $this->config['host'] . ' '
	. 'password=' . $this->config['pass'] . ' ';
      
      if ($this->db = pg_pconnect($dsn)) {
	return $this;
      }
      else {
	throw  new BadMethodCallException('DB connect failed');
      }
    }
    
    return $this;
    
  } // End function connect


  /**
   *
   * Escaping eines Strings fuer ein Query, nur ein wrapper fuer die
   * DB-spezifische Methode, hier eben pg_escape_string
   *
   * @param string $in
   * @return string
   * @access public
   *
   */
  public function escape($in) {
  
    return pg_escape_string($in);
    
  } // End function escape


  
    /**
     *
     * Funktion die ein Query an die DB schickt, und daraus ein Array
     * zurueckgibt
     *
     * Funktion die ein Query an die DB schickt, und daraus ein Array baut
     * und zurueck gibt. Mit dem optionalen Parameter $id kann der Name
     * eines Keys/row angegeben werden, der dann als primaerer Key fuer das
     * Array genutzt wird, ansonsten die skalare Default Nummerierung.
     *
     * @param string $query
     * @return array
     * @access public
     *
     */
  public function query_to_array($query, $id=FALSE) {

    $output = array();

    if ($result = pg_query($this->db, $query)) {

      while ($row = pg_fetch_assoc($result)) {

        // soll nach einen Key sortiert werden?
        if ($id) {

          if (array_key_exists($id, $row)) {

            $output[$row[$id]] = $row;

          }
          else {
            trigger_error('FW_Storage: SortierKey nicht in result gefunden!'
                          , E_USER_WARNING);
            return array();
          }
        }
        else {

          $output[] = $row;

        }
      }

      return $output;

    }
    else {

      trigger_error("FW_Storage: Query fehlgeschlagen:["
                    . $query . "]"
                    . pg_last_error(), E_USER_WARNING);

      return array();

    }

  } // End function query_to_array

  


  } // End class osfwDB

// EOF
