<?php
  /**
   *
   * Base Klasse der Views
   *
   * @version $Id: page.php,v 1.13 2010/04/09 15:35:11 jg Exp $
   * @package osfw
   * @author  <webdev@LF.net>
   * @copyright 2010, LF.net
   *
   */

  /**
   *
   * Base Klasse fuer die Anzeige der versch. Views des OSFW
   * WebInterfaces
   *
   */
class osfwPage {
  
  /**
   *
   * Request Vars POST|GET
   * @var array
   * @access protected
   *
   */
  protected $FORM_VARS = array();
  
  /**
   *
   * Action Param, was soll denn gemacht werden?
   * @var string
   * @access protected
   *
   */
  protected $action = false;
  
  /**
   *
   * Template Vars, Array mit Werten auf die in den Templates zugegriffen
   * werden kann
   * @var array
   * @access protected
   *
   */
  protected $tmpl = array('msg' => '',
			  'title' => '__TITLE__',
			  'custom_css' => '',
			  'content' => 'Inhalt',
			  'tmpl_base_url' => OSFW_TMPL_BASE_URL,
			  );
  
  /**
   *
   * Struct der moeglichen Optionen einer Page die ueber setOptions
   * gesetzt werden koennen
   * @var array
   * @access protected
   *
   */
  protected $options = array('per_page' => 25,
			     'offset'   => 0,
			     'refresh'  => 10,
			     );


  /**
   *
   * Array aus dem die Main-Navi der Seiten erzeugt wird
   * @var array
   * @access protected
   *
   */
  protected $main_navi = array('Firewall Logs' => 'fwlog',
			       'Firewall active connections' => 'fwconn',
			       'VPN active connections' => 'vpnconn',
			       'VPN archived connections' => 'vpnconn_arch',
			       );
  
 
  /**
   *
   * Query Parts die in SubMethoden erstellt werden um daraus die
   * GesamtQueries zu erzeugen
   * @var array
   * @access protected
   *
   */
  protected $q_parts = array('where' => array(),
			     'order' => array());
  

  /**
   * Array mit den RohDaten aus der DB
   * @var array
   * @access protected
   */
  protected $raw_data = array('count' => 0,
			      'rows'  => array());
  
  
  /**
   *
   * Array ueber das fuer die versch. Tabellen die Spalten Namen mit den
   * FilterKeys gemappt werden
   * @var array
   * @access protected
   *
   */
  protected $filter_row_map;
 
  /**
   *
   * Das DB Objekt, wird je nach Aktion erstellt
   * @var object
   * @access protected
   *
   */
  protected $db;
  
  /**
   *
   * Array mit connection-Daten fuer die DB-Connects
   * @var array
   * @access protected
   *
   */
  protected $db_conf;
 
  
  /**
   *
   * Konstruktor, der triggert alles weitere
   *
   * @param array $db_conf
   * @return void
   * @access public
   *
   */
  public function __construct($db_conf) {
    
    $this->db_conf = $db_conf;
    $this->init();
    $this->switchAction();

  } // End function __construct
  
  /**
   *
   * Initialisierung je nach Request
   *
   * @return void
   * @access public
   *
   */
  public function init() {
    
    // GET oder POST? 
    if (isset($_POST['action'])) {
      $this->action = $_POST['action']; 
      $this->FORM_VARS = $_POST;
    }
    if (isset($_GET['action'])) {
      $this->action = $_GET['action']; 
      $this->FORM_VARS = $_GET;
    }
    
    if (isset($this->FORM_VARS['options'])
	&& is_array($this->FORM_VARS['options'])) {
      $this->setOptions($this->FORM_VARS['options']);
    }
    
  } // End function init
  
  /**
   *
   * Triggert je nach action die weiteren notwendigen Dinge
   *
   * @todo einen huebscheren Weg finden wie wir versch. DBs an die
   * Methoden binden, eventuell eben doch mit eigenen Modell- Klassen.
   * 
   * @return void
   * @access protected
   *
   */
  protected function switchAction() {
    
    switch ($this->action) {
    case 'fwlog':
      $this->db = new osfwDB($this->db_conf['fwlog']);
      $this->tmpl['title'] = "FW-Logs";
      $this->fwlog();
      break;
      
    case 'fwconn':
      $this->db = new osfwDB($this->db_conf['fwlog']);
      $this->tmpl['title'] = "FW-Connections";
      $this->fwconn();
      break;
      
    case 'vpnconn':
      $this->db = new osfwDB($this->db_conf['vpn']);
      $this->tmpl['title'] = "VPN-Connections";
      $this->vpnconn();
      break;

    case 'vpnconn_arch':
      $this->db = new osfwDB($this->db_conf['vpn']);
      $this->tmpl['title'] = "Archived VPN-Connections";
      $this->vpnconn_arch();
      break;
      
      // Default leite ich aktuell auf die FW-Logs Seite
    default:
      $this->action = 'fwlog';
      $this->db = new osfwDB($this->db_conf['fwlog']);
      $this->tmpl['title'] = "FW-Logs";
      $this->fwlog();
      // $this->tmpl['title'] = "Startseite";
      // $this->overview();
      break;
    }
		
  } // End function switchAction
  
  
  /**
   *
   * Ausgabe der gerenderten Seite
   *
   * @return void
   * @access public
   *
   */
  public function out() {

    $this->buildMainNavi();
    $this->tmpl['options'] = $this->options;
  
    // shortcut fuer das Template
    $tmpl = $this->tmpl;
    $FORM_VARS = $this->FORM_VARS;

    ob_start();
    include(OSFW_TMPL_FILE);
    $page = ob_get_clean();

    echo $page;

  } // End function out

  
  /**
   *
   * Haengt einen message-string an die entspr. TemplateVariable
   *
   * @param string $msg
   * @param string $type false | w = warning | e = error
   * @return void
   * @access protected
   *
   */
  protected function msg($msg, $type = false) {
    
    $class = 'msg';
    if ($type == 'w') {
      $class .= ' warn';
    }
    if ($type == 'e') {
      $class .= ' error';
    }

    $this->tmpl['msg'] .= '<p class="' . $class . '">' . $msg . '</p>' . PHP_EOL;
    
  } // End function msg


  /**
   *
   * Setzt die Page Optionen wie refresh-time, row-per-page, etc.
   *
   * @todo Eingabe validierung, eventuell ueber Struct definition
   * 
   * @param array $options
   * @return object
   * @access public
   *
   */
  public function setOptions(array $options) {
    
    foreach ($options as $key => $value) {

      if (array_key_exists($key, $this->options)) {
	$this->options[$key] = $value;
      }
      
      // DOS ueber JS Refresh abfangen ;-)
      if ($this->options['refresh'] < 5) {
	$this->options['refresh'] = 5;
      }
      
    }

  } // End function setOptions
  

  /**
   *
   * Baut den HTML-Schnippsel der im Template als MainNavi angezeigt
   * wird und setzt den entspr. Wert in this->tmpl
   *
   * @return void
   * @access public
   *
   */
  public function buildMainNavi() {
    
    $this->tmpl['main_navi'] = '<ul>' . PHP_EOL;
    foreach ($this->main_navi as $name => $action) {

      $link = $_SERVER['SCRIPT_NAME'] . '?action=' . $action;

      $class = '';
      if ($this->action == $action) {
	$class = 'class="active"';
      }

      $this->tmpl['main_navi'] 
	.= '<li><a ' . $class . ' href="' . $link . '">' . $name . '</a></li>' . PHP_EOL;
    }
    $this->tmpl['main_navi'] .= '</ul>' . PHP_EOL;    

  } // End function buildMainNavi


  /**
   *
   * Baut die Links und Hints fuer den Pager im Tabellen-Footer zusammen
   *
   * @return string
   * @access public
   *
   */
  public function buildDataPager() {
    
    $page_count = ceil($this->raw_data['count'] / $this->options['per_page']);

    // Page Count
    $tmp[] = '<span class="pcount">Page Count: ' . $page_count . '</span>';

    // Anzahl matches/rows
    $tmp[] = '<span class="rcount">Total matches: ' 
      . $this->raw_data['count'] . '</span>';
    
    $prev  = $this->options['offset'] - $this->options['per_page'];
    $next = $this->options['offset'] + $this->options['per_page'];

    // Prev/Next usw. nur wen nes was zu sehen gibt
    if ($page_count) {
      
      // Prev-Links
      if ($prev >= 0) {

	// Dann auch ein Start-Link
	$this->FORM_VARS['offset'] = 0;
	$href = $_SERVER['SCRIPT_NAME'] . "?"  
	  . http_build_query($this->FORM_VARS, '', '&amp;'); 
	$tmp[] = '<span class="start"><a href="' . $href . '">Start</a></span>';

	// Der Prev-Link selber
	$this->FORM_VARS['offset'] = $prev;
	$href = $_SERVER['SCRIPT_NAME'] . "?" 
	  . http_build_query($this->FORM_VARS, '', '&amp;');
	
	$tmp[] = '<span class="prev"><a href="' . $href . '">Prev ' 
	  . $this->options['per_page'] . '</a></span>';	
      }
      else {
	$tmp[] = '<span class="prev">Prev ' . $this->options['per_page'] . '</span>';
      }
      
      // Next-Links
      if ($next <= $this->raw_data['count']) {
	$this->FORM_VARS['offset'] = $next;
	$href = $_SERVER['SCRIPT_NAME'] . "?" 
	  . http_build_query($this->FORM_VARS, '', '&amp;');
	
	$tmp[] = '<span class="next"><a href="' . $href . '">Next ' 
	  . $this->options['per_page'] . '</a></span>';
      }
      else {
	$tmp[] = '<span class="next">Next ' . $this->options['per_page'] . '</span>';
      }
      
    } // Ende Prev/Next if
    
    // debug($this->tmpl);
    // debug($this->options);
    
    $pager = '<div class="pager">' . join(' ' . PHP_EOL, $tmp) . '</div>' . PHP_EOL;
    
    return $pager;
    
  } // End function buildDataPager
  

  /**
   *
   * Baut aus Header, Data; und Template die DatenTabelle fuer die
   * Ausgabe zusammen (wenn es Daten gibt...)
   *
   * @param array $header
   * @param array $data
   * @param string $tmpl
   * @return void
   * @access protected
   *
   */
  protected function buildDataTable($header, $data, $tmpl) {

    if(! $this->raw_data['count']){
      $this->msg('No records matched your query');
      # leere dummy-Daten erstellen damit die HTML-Tabelle nicht korupt wird
      $data[] = array_pad(array(), count($header), '-');
    }
    
    ob_start();
    $footer = $this->buildDataPager();
    include(OSFW_TMPL_DIR . '/' . $tmpl);
    $this->tmpl['content'] = ob_get_clean();
    
  } // End function buildDataTable
  
 
  # ------------------------------------------------------------
  // Methoden die die Ausgaben erzeugen, koennen/sollten bei Bedarf in
  // eigene Klassen ausgelagert werden
  # ------------------------------------------------------------

  /**
   *
   * Erzeugt die Ausgaben aus den FW-Log Tabellen
   *
   * @return void
   * @access protected
   *
   */
  protected function fwlog() {
  
    $this->tmpl['content'] = __METHOD__;

    $this->filter_row_map = array('dest_ip' => 'ip_daddr_str',
				  'src_ip'  => 'ip_saddr_str',
				  'dest_port' => array('tcp_dport', 'udp_dport'),
				  'src_port' => array('tcp_sport', 'udp_sport'),
				  'proto'     => 'ip_protocol',
				  );

    
    $this->filter_ip();
    $this->filter_port();
    $this->filter_proto();

    $w_filter = $this->getWhereFilter(); 
    $o_filter = $this->getOrderFilter(); 
    $l_filter = $this->getLimitFilter();    

    $q_count = "SELECT COUNT(*) FROM ulog WHERE 1 = 1" . $w_filter;
    $q_data  = "SELECT * FROM ulog WHERE 1 = 1" . $w_filter 
      . " ORDER BY oob_time_sec DESC, oob_time_usec DESC " . $o_filter . $l_filter;
    
    // Daten mit den beiden Queries in $this->raw_data einlesen
    $this->getRawData($q_count, $q_data);
    
    // Aus den Roh-Daten die Werte raussuchen die angezeigt werden und
    // ggfs. Format anpassen
    $data = array();
    foreach ($this->raw_data['rows'] as $key => $values) {
      
      $row = array();

      // Manche Info bekommen wir als String den wir erst mal zerlegen muessen
      // [oob_prefix] => osfw-v3 -- RULE 12 -- DENY
      list($module, $rule_nr, $action) = array_map('trim', explode('--', $values['oob_prefix']));

      $row['timestamp']    = $this->dateFormat($values['oob_time_sec']);
      $row['module'] = $module;
      $row['rule_nr'] = $rule_nr;
      $row['action'] = $action;
      $row['proto']        = getprotobynumber($values['ip_protocol']);
      $row['oob_in'] = $values['oob_in'];
      $row['oob_out'] = $values['oob_out'];
      $row['src_ip'] = $values['ip_saddr_str'];
      $row['src_port'] = $values['tcp_sport'] ? $values['tcp_sport'] : $values['udp_sport'];
      $row['dest_ip'] = $values['ip_daddr_str'];
      $row['dest_port'] = $values['tcp_dport'] ? $values['tcp_dport'] : $values['udp_dport'];;
      $row['fw_mark'] = $values['oob_mark'];
      
      $data[] = $row;
      
    }  

    // debug($data);

    $header = array('Timestamp', 
		    'FW Module', 
		    'Rule Number', 
		    'Action', 
		    'Protocol', 
		    'Input IF', 
		    'Output IF', 
		    'Source IP', 
		    'Source Port', 
		    'Dest IP', 
		    'Dest Port',
		    'FW Mark');
    
    
    $this->buildDataTable($header, $data, 'osfw_data_table.html');
    
  } // End function fwlog

  /**
   *
   * Erzeugt die Ausgaben aus den FW-Connection Tabellen
   *
   * @return void
   * @access protected
   *
   */
  protected function fwconn() {

    $this->tmpl['content'] = __METHOD__;

    $this->filter_row_map = array('dest_ip' => 'orig_ip_daddr_str',
				  'src_ip'  => 'orig_ip_saddr_str',
				  'dest_port' => 'orig_l4_dport',
				  'src_port' => 'orig_l4_sport',
				  'proto'     => 'orig_ip_protocol',
				  );

    $this->filter_ip();
    $this->filter_port();
    $this->filter_proto();

    $w_filter = $this->getWhereFilter(); 
    $o_filter = $this->getOrderFilter(); 
    $l_filter = $this->getLimitFilter();    

    $q_count = "SELECT COUNT(*) FROM conntrack WHERE 1 = 1 " . $w_filter;
    $q_data = "SELECT * FROM conntrack WHERE 1 = 1 " . $w_filter
      . " ORDER BY flow_start_sec DESC " . $o_filter . $l_filter;

    // Daten mit den beiden Queries in $this->raw_data einlesen 
    $this->getRawData($q_count, $q_data);

    // Aus den Roh-Daten die Werte raussuchen die angezeigt werden und
    // ggfs. Format anpassen.
    $data = array();
    foreach ($this->raw_data['rows'] as $key => $values) {

      $row = array();
      
      $row['timestamp']    = $this->dateFormat($values['flow_start_sec']);
      $row['proto']        = getprotobynumber($values['orig_ip_protocol']);
      $row['src_ip'] = $values['orig_ip_saddr_str'];
      $row['src_port'] = $values['orig_l4_sport'];
      $row['dest_ip'] = $values['orig_ip_daddr_str'];
      $row['dest_port'] = $values['orig_l4_dport'];
      $row['ct_mark'] = $values['ct_mark'];	
      
      $data[] = $row;
      
    }  

    // debug($data);

    $header = array('Timestamp', 
		    'Protocol',
		    'Source IP', 
		    'Source Port', 
		    'Dest IP', 
		    'Dest Port',
		    'Conn Mark');
    

    $this->buildDataTable($header, $data, 'osfw_data_table.html');
    
  } // End function fwconn

  /**
   *
   * Erzeugt die Ausgaben der VPN-Connections
   * 
   * Methode kann fuer ARCH Ansicht wiederverwendet werden, dann eben
   * FALSE als conn_state Param
   *
   * @param string $conn_state default TRUE, 
   * @return void
   * @access protected
   *
   */
  protected function vpnconn($conn_state = 'TRUE') {
  
    $this->tmpl['content'] = __METHOD__;


    $this->filter_row_map = array('src_ip' => 'real_address',
				  'dest_ip'  => 'virtual_address',
				  'conn_id' => 'conn_id',
				  );
    
    $this->filter_ip();
    $this->filter_conn_id();

    $w_filter = $this->getWhereFilter(); 
    $o_filter = $this->getOrderFilter(); 
    $l_filter = $this->getLimitFilter();    

    $q_count = "SELECT COUNT(*) FROM client_list_fw1 WHERE conn_state = '" . $conn_state . "' " . $w_filter;
    $q_data = "SELECT * FROM client_list_fw1 WHERE conn_state = '" . $conn_state . "' " . $w_filter
      . " ORDER BY conn_since DESC " . $o_filter . $l_filter;
    
    // Daten mit den beiden Queries in $this->raw_data einlesen 
    $this->getRawData($q_count, $q_data);

    // Aus den Roh-Daten die Werte raussuchen die angezeigt werden und
    // ggfs. Format anpassen.
    $data = array();
    foreach ($this->raw_data['rows'] as $key => $values) {
      
      $row = array();
      
      $row['conn_id'] = $values['conn_id'];
      $row['common_name'] = $values['common_name'];
      $row['src_ip'] = $values['real_address'];
      $row['dest_ip'] = $values['virtual_address'];
      $row['bytes_sent'] = $this->getByteSize($values['bytes_sent']);
      $row['bytes_recv'] = $this->getByteSize($values['bytes_recv']);
      $row['bytes_total'] = $this->getByteSize($values['bytes_sent'] + $values['bytes_recv']);
      $row['conn_since'] = $this->dateFormat($values['conn_since']);
      $row['last_ref'] = $this->dateFormat($values['last_ref']);
      $row['last_update'] = $this->dateFormat($values['last_update']);
      
      $data[] = $row;
      
    }  

    // debug($data);

    $header = array('Name', 
		    'Remote IP',
		    'VPN IP',
		    'Recv Bytes',
		    'Sent Bytes',
		    'Total Bytes',
		    'Conn since',
		    'Last ref.',
		    'Last Updt',
		    );
    

    $this->buildDataTable($header, $data, 'vpnconn_table.html');
    
  } // End function vpnconn

  /**
   *
   * Erzeugt die Ausgaben der archived VPN-Connections, ruft dafuer
   * $this->vpnconn('FALSE') auf
   *
   * @return void
   * @access protected
   *
   */
  protected function vpnconn_arch() {
  
    $this->tmpl['content'] = __METHOD__;

    $this->vpnconn('FALSE');

  } // End function vpnconn_arch

  
  /**
   *
   * Bekommt die beiden Queries fuer den count() und die Daten und
   * liefert den count-wert und das Daten-Array fuer die Ausgabe
   *
   * Der erste Query MUSS ein "SELECT COUNT(*)...." sein, anhand dieses
   * Wertes wird dann entschieden, ob es ueberhaupt daten zum auslesen
   * gibt.
   * 
   * Liefert Daten fuer $this->raw_data Array mit folgender struktur:
   * 
   * array('rowcount' => Ergebnis von $q_count, 
   *       'data'     => array($row1,$row2,...));
   * 
   * @param string $q_count
   * @param string $q_data
   * @return void
   * @access protected
   *
   */
  protected function getRawData($q_count, $q_data) {
        
    // debug($q_count);
    // debug($q_data);
    
    // Nur Daten holen wenn es auch welche fuer die Filter gibt
    $raw_count = $this->db->query_to_array($q_count);
    if (!empty($raw_count[0])
	&& $raw_count[0]['count']) {
      $this->raw_data['count'] = $raw_count[0]['count'];
      $this->raw_data['rows']  = $this->db->query_to_array($q_data);
    }
    
    // debug($this->raw_data);

  } // End function getRawData

  # ------------------------------------------------------------
  // Methoden fuer die SELECT-Filter. Diese erstellen generische
  // Teil-Querys. legen diese im Array $this->q_parts ab so dass
  // daraus dann die gesamt Querys zusammengebaut werden koennen.
  # ------------------------------------------------------------
  
  /**
   *
   * Liefert den "LIMIT..." Teil des Queries fuer Seitenweise anzeige
   *
   * @return string
   * @access protected
   *
   */
  protected function getLimitFilter() {
    
    if (isset($this->FORM_VARS['offset'])
	&& (int) $this->FORM_VARS['offset']) {
      $this->options['offset'] = (int) $this->FORM_VARS['offset'];
    }
    
    return " LIMIT " . $this->options['per_page'] . " OFFSET " . $this->options['offset'];
    
  } // End function getLimitFilter


  /**
   *
   * liefert den SQL-String der Filter der im "WHERE...." Teil fuer
   * einen Query verwendet werden kann
   *
   * @return string
   * @access protected
   *
   */
  protected function getWhereFilter() {
    
    if (count($this->q_parts['where'])) {
      return ' AND ' . join(' AND ', $this->q_parts['where']);
    }
    
    return '';

  } // End function getWhere

  /**
   *
   * liefert den SQL-String der ilter der im "WHERE...." Teil fuer
   * einen Query verwendet werden kann
   *
   * @return string
   * @access protected
   *
   */
  protected function getOrderFilter() {
    
    if (count($this->q_parts['order'])) {
      return join(', ', $this->q_parts['order']);
    }
    
    return '';

  } // End function getOrder

  /**
   *
   * Baut den SQL-Const- String fuer einen Filter aus den FilterValues
   * und den row_mapper Keys zusammen
   *
   * @param mixed $keys
   * @param string $value
   * @return string
   * @access protected
   *
   */
  protected function getConstString($keys, $value) {
    
    if (is_array($keys)) {
      $tmp = array();
      foreach($keys as $key){
	$tmp[]  = $key . " = '" . $this->db->escape($value) . "'";
      }
      $const = '(' . join(' OR ', $tmp) . ')';
    }
    else {
      $const = $keys . " = '" . $this->db->escape($value) . "'";
    }

    return $const;

  } // End function getConstString
  
  /**
   *
   * Erzeugt den SQL-Teil fuer IP-Filter
   *
   * @return void
   * @access protected
   *
   */
  protected function filter_ip() {
    
    if (!empty($this->FORM_VARS['dest_ip'])) {
      if ($this->validate_ip($this->FORM_VARS['dest_ip'])) {
	$this->q_parts['where'][] = $this->getConstString($this->filter_row_map['dest_ip'], 
							  $this->FORM_VARS['dest_ip']);
      }
      else {
	$this->msg('Unvalid filter IP', 'w');
	$this->FORM_VARS['dest_ip'] = '';
      }
    }
    if (!empty($this->FORM_VARS['src_ip'])){
      if ($this->validate_ip($this->FORM_VARS['src_ip'])) {
	$this->q_parts['where'][] = $this->getConstString($this->filter_row_map['src_ip'], 
							  $this->FORM_VARS['src_ip']);
      }
      else {
	$this->msg('Unvalid filter IP', 'w');
	$this->FORM_VARS['src_ip'] = '';
      }
    }
    
  } // End function filter_ip

  /**
   *
   * Erzeugt den SQL-Teil fuer Port-Filter
   *
   * @return void
   * @access protected
   *
   */
  protected function filter_port() {
    
    if (!empty($this->FORM_VARS['dest_port'])) {
      if ((int)$this->FORM_VARS['dest_port']) {
	$this->q_parts['where'][] = $this->getConstString($this->filter_row_map['dest_port'], 
							  $this->FORM_VARS['dest_port']);
      }
      else {
	$this->msg('Unvalid filter port', 'w');
	$this->FORM_VARS['dest_port'] = '';
      }
    }
    if (!empty($this->FORM_VARS['src_port'])){
      if ((int)$this->FORM_VARS['src_port']) {
	$this->q_parts['where'][] = $this->getConstString($this->filter_row_map['src_port'], 
							  $this->FORM_VARS['src_port']);
      }
      else {
	$this->msg('Unvalid filter port', 'w');
	$this->FORM_VARS['src_port'] = '';
      }
    }
        
  } // End function filter_port


  /**
   *
   * Erzeugt den SQL-Teil fuer Protokoll-Filter
   *
   * @return void
   * @access protected
   *
   */
  protected function filter_proto() {
    
    $protocolls = array ('ip','icmp','ggp','tcp',
			 'egp','pup','udp','hmp','xns-idp',
			 'rdp','rvd');
    
    if (!empty($this->FORM_VARS['proto'])) {
      
      $in = strtolower($this->FORM_VARS['proto']);
      
      if (in_array($in, $protocolls)) {
	
	$proto = getprotobyname($in);
	
	$this->q_parts['where'][] = $this->getConstString($this->filter_row_map['proto'],
							  $proto);
      }
      else {
	$this->msg('Unvalid filter protocol', 'w');
	$this->FORM_VARS['proto'] = '';
      }
    }
    
  } // End function filter_proto

  /**
   *
   * Erzeugt die conn_id Filter fuer vpnlogs
   *
   * @return void
   * @access protected
   *
   */
  protected function filter_conn_id() {
    
    if (!empty($this->FORM_VARS['conn_id'])) { 
      
      $this->q_parts['where'][] = $this->getConstString($this->filter_row_map['conn_id'],
							$this->FORM_VARS['conn_id']);
      
    }

  } // End function filter_conn_id
  

/**
 *
 * Validiert eine IP
 *
 * @param string $ip
 * @return mixed
 * @access public
 *
 */
  public function validate_ip($ip) {
    
    return filter_var($ip, FILTER_VALIDATE_IP);
    
  } // End function validate_ip



  /**
   *
   * Formatiert ein timestamp fuer die Ausgabe
   *
   * @param integer $timestamp
   * @return string
   * @access protected
   *
   */
  protected function dateFormat($timestamp) {
    
    return date(DATE_RFC822, $timestamp);
    
  } // End function dateFormat

  /* 
   * Methode zur Byte Berechnung, von dt@ 1:1 uebernommen
   * 
   * @param integer $size
   * @return string
   * @access protected
   */ 
  protected function getByteSize($size) {
    $si = array('B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB');
    $remainder = $i = 0;
    while ($size >= 1024 && $i < 8) {
      $remainder = (($size & 0x3ff) + $remainder) / 1024;
      $size = $size >> 10;
      $i++;
    }
    return round($size + $remainder, 2) . ' ' . $si[$i];
  } // End function getByteSize

 
  } // End class osfwPage
// EOF
